@@ -220,13 +220,23 @@ class ImageItem(Item):
             # First try to use the tilesource we recorded as the preferred one.
             # This is faster than trying to find the best source each time.
             tileSource = girder_tilesource.AvailableGirderTileSources[sourceName](item, **kwargs)
-        except TileSourceError:
+        except TileSourceError as exc:
             # We could try any source
             # tileSource = girder_tilesource.getGirderTileSource(item, **kwargs)
             # but, instead, log that the original source no longer works are
             # reraise the exception
             logger.warning('The original tile source for item %s is not working' % item['_id'])
-            raise
+            try:
+                file = File().load(item['largeImage']['fileId'], force=True)
+                localPath = File().getLocalFilePath(file)
+                open(localPath, 'rb').read(1)
+            except IOError:
+                logger.warning(
+                    'Is the original data reachable and readable (it fails via %r)?', localPath)
+                raise IOError(localPath) from None
+            except Exception:
+                pass
+            raise exc
         return tileSource
 
     def getMetadata(self, item, **kwargs):
@@ -406,7 +416,8 @@ class ImageItem(Item):
                 logger.warning('Could not cache data for large image')
         return imageData, imageMime
 
-    def removeThumbnailFiles(self, item, keep=0, sort=None, imageKey=None, **kwargs):
+    def removeThumbnailFiles(self, item, keep=0, sort=None, imageKey=None,
+                             onlyList=False, **kwargs):
         """
         Remove all large image thumbnails from an item.
 
@@ -416,6 +427,8 @@ class ImageItem(Item):
             sort order are kept.
         :param imageKey: None for the basic thumbnail, otherwise an associated
             imageKey.
+        :param onlyList: if True, return a list of known thumbnails or data
+            files that would be removed, but don't remove them.
         :param kwargs: additional parameters to determine which files to
             remove.
         :returns: a tuple of (the number of files before removal, the number of
@@ -426,6 +439,9 @@ class ImageItem(Item):
             keys.append('isLargeImageData')
         if not sort:
             sort = [('_id', SortDir.DESCENDING)]
+        results = []
+        present = 0
+        removed = 0
         for key in keys:
             query = {
                 'attachedToType': 'item',
@@ -438,15 +454,18 @@ class ImageItem(Item):
                 else:
                     query['thumbnailKey'] = {'$regex': '"imageKey":"%s"' % imageKey}
             query.update(kwargs)
-            present = 0
-            removed = 0
             for file in File().find(query, sort=sort):
                 present += 1
                 if keep > 0:
                     keep -= 1
                     continue
-                File().remove(file)
+                if onlyList:
+                    results.append(file)
+                else:
+                    File().remove(file)
                 removed += 1
+        if onlyList:
+            return results
         return (present, removed)
 
     def getRegion(self, item, **kwargs):
